@@ -97,6 +97,9 @@ OC.L10N.register(
     "Could not write file to disk" : "Soubor se nedaří se zapsat na úložiště",
     "A PHP extension stopped the file upload" : "PHP rozšíření zastavilo nahrávání souboru.",
     "No file uploaded or file size exceeds maximum of %s" : "Nebyl nahrán žádný soubor nebo jeho velikost přesáhla %s",
+    "Card not found" : "Karta nebyla nalezena",
+    "Path is already shared with this card" : "Cesta je již s touto kartou sdílena",
+    "Invalid date, date format must be YYYY-MM-DD" : "Neplatné datum, formát data musí být RRRR-MM-DD",
     "Personal planning and team project organization" : "Osobní plánování a organizování týmového projektu",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck je nástroj cílený na osobní nebo projektové plánování týmů v Kanban stylu, vestavěný v Nextcloud.\n\n\n- 📥 Zadávejte a uspořádávejte své úkoly do karet\n- 📄 Zapisujte si dodatečné poznámky \n- 🔖 Přiřazujte štítky pro ještě lepší organizaci\n- 👥 Sdílejte se svým týmem, přáteli nebo rodinou\n- 🚀 Dostaňte svůj projekt pod kontrolu",
     "Card details" : "Podrobnosti o kartě",
@@ -104,11 +107,11 @@ OC.L10N.register(
     "Select the board to link to a project" : "Vyberte tabuli kterou propojit s projektem",
     "Search by board title" : "Hledat podle názvu tabule",
     "Select board" : "Vybrat tabuli",
-    "Select the card to link to a project" : "Vyberte kartu kterou propojit s projektem",
     "Select a board" : "Vybrat tabuli",
     "Select a card" : "Vybrat tabuli",
-    "Link to card" : "Propojit s kartou",
     "Cancel" : "Storno",
+    "Select the card to link to a project" : "Vyberte kartu kterou propojit s projektem",
+    "Link to card" : "Propojit s kartou",
     "File already exists" : "Soubor už existuje",
     "A file with the name {filename} already exists." : "Soubor nazvaný {filename} už existuje.",
     "Do you want to overwrite it?" : "Chcete položku přepsat?",
@@ -169,10 +172,15 @@ OC.L10N.register(
     "title and color value must be provided" : "je třeba zadat nadpis a zvolit barvu",
     "Board name" : "Název tabule",
     "Members" : "Členové",
-    "Upload attachment" : "Nahrát přílohu",
+    "Upload new files" : "Nahrát nové soubory",
+    "Share from Files" : "Sdílet ze Souborů",
     "Add this attachment" : "Přidat tuto přílohu",
+    "Show in Files" : "Zobrazit v Souborech",
+    "Unshare file" : "Přestat sdílet soubor",
     "Delete Attachment" : "Smazat přílohu",
     "Restore Attachment" : "Obnovit přílohu",
+    "File to share" : "Soubor ke sdílení",
+    "Invalid path selected" : "Je vybrána neplatná cesta",
     "Open in sidebar view" : "Otevřít v zobrazení v postranním panelu",
     "Open in bigger view" : "Otevřít ve větším zobrazení",
     "Attachments" : "Přílohy",
@@ -219,6 +227,7 @@ OC.L10N.register(
     "All boards" : "Všechny tabule",
     "Archived boards" : "Archivované tabule",
     "Shared with you" : "Sdíleno s vámi",
+    "Use bigger card view" : "Použít větší zobrazení karet",
     "Show boards in calendar/tasks" : "Zobrazit tabule v kalendáři/úkolech",
     "Limit deck usage of groups" : "Omezit využití deck na skupiny",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "Omezení nastavené pro Deck brání uživatelům, kteří nejsou součástí těchto skupin, ve vytváření vlastních tabulí. Nicméně i tak ale pořád budou moci pracovat na tabulích, které jsou jim nasdíleny.",
@@ -250,6 +259,11 @@ OC.L10N.register(
     "Link to a board" : "Propojit s tabulí",
     "Link to a card" : "Propojit s kartou",
     "Something went wrong" : "Něco se pokazilo",
-    "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}"
+    "Failed to upload {name}" : "Nepodařilo se nahrát {name}",
+    "Maximum file size of {size} exceeded" : "Překročena nejvyšší umožněná velikost souboru {size}",
+    "Error creating the share" : "Chyba při vytváření sdílení",
+    "Share with a Deck card" : "Sdílet kartu aplikace Deck",
+    "Share {file} with a Deck card" : "Sdílet {file} s kartou aplikace Deck",
+    "Share" : "Sdílet"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
