@@ -97,6 +97,9 @@ OC.L10N.register(
     "Could not write file to disk" : "לא ניתן לכתוב לכונן",
     "A PHP extension stopped the file upload" : "הרחבת PHP עצרה את העלאת הקובץ",
     "No file uploaded or file size exceeds maximum of %s" : "לא הועלה אף קובץ או שגודל הקובץ חרג מהסף המרבי של %s",
+    "Card not found" : "כרטיס לא נמצא",
+    "Path is already shared with this card" : "הנתיב כבר משותף עם הכרטיס הזה",
+    "Invalid date, date format must be YYYY-MM-DD" : "תאריך שגוי, תבנית התאריך חייבת להיות YYYY-MM-DD",
     "Personal planning and team project organization" : "ארגון אישי וקבוצתי של מיזמים",
     "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "Deck הוא כלי ארגון בסגנון kanban המכוון לתכנון אישי ולארגון פרויקטים עבור צוותים המשולבים ב- Nextcloud.\n\n\n- 📥 הוסף את המשימות שלך לכרטיסים וסדר אותן\n- 📄 רשמו הערות נוספות ב-markdown\n- 🔖הקצה תוויות לארגון טוב עוד יותר\n- 👥 שתף עם הצוות שלך, חברים, או משפחה\n- 📎 צרף קבצים והטמע אותם בתיאור ה-markdown שלך\n- 💬 שוחח עם הצוות שלך באמצעות הערות\n- ⚡ עקוב אחר שינויים בזרם הפעילות\n- 🚀 ארגנו את הפרויקט שלכם",
     "Card details" : "פרטי הכרטיס",
@@ -104,11 +107,11 @@ OC.L10N.register(
     "Select the board to link to a project" : "נא לבחור את הלוח לקישור למיזם",
     "Search by board title" : "חיפוש לפי כותרת לו",
     "Select board" : "בחירת לוח",
-    "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
     "Select a board" : "נא לבחור לוח",
     "Select a card" : "נא לבחור כרטיס",
-    "Link to card" : "קישור לכרטיס",
     "Cancel" : "ביטול",
+    "Select the card to link to a project" : "נא לבחור את הכרטיס לקישור למיזם",
+    "Link to card" : "קישור לכרטיס",
     "File already exists" : "הקובץ כבר קיים",
     "A file with the name {filename} already exists." : "כבר קיים קובץ עם השם {filename}.",
     "Do you want to overwrite it?" : "לשכתב עליו?",
@@ -169,10 +172,15 @@ OC.L10N.register(
     "title and color value must be provided" : "יש לספק כותרת וערך צבע",
     "Board name" : "שם הלוח",
     "Members" : "חברים",
-    "Upload attachment" : "העלאת קבצים מצורפים",
+    "Upload new files" : "העלאת קבצים חדשים",
+    "Share from Files" : "שיתוף מקבצים",
     "Add this attachment" : "הוספת קובץ מצורף זה",
+    "Show in Files" : "הצגה בקבצים",
+    "Unshare file" : "ביטול שיתוף קובץ",
     "Delete Attachment" : "מחיקת קובץ מצורף",
     "Restore Attachment" : "שחזור קובץ מצורף",
+    "File to share" : "קובץ לשיתוף",
+    "Invalid path selected" : "הנתיב שנבחר שגוי",
     "Open in sidebar view" : "פתח בתצוגת סרגל הצד",
     "Open in bigger view" : "פתח בתצוגה גדולה יותר",
     "Attachments" : "קבצים מצורפים",
@@ -219,6 +227,7 @@ OC.L10N.register(
     "All boards" : "כל הלוחות",
     "Archived boards" : "לוחות שנשמרו בארכיון",
     "Shared with you" : "משותף אתך",
+    "Use bigger card view" : "להשתמש בתצוגת כרטיסים גדולה יותר",
     "Show boards in calendar/tasks" : "הצג הלוחות בלוח השנה/המשימות",
     "Limit deck usage of groups" : "הגבלת השימוש בחבילה לקבוצות",
     "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "הגבלת חבילה תחסום משתמשים שאינם חלק מקבוצות אלו מיצירת לוחות משלהם. משתמשים עדיין יוכלו לעבור על לוחות ששותפו אתם.",
@@ -251,6 +260,10 @@ OC.L10N.register(
     "Link to a card" : "קישור לכרטיס",
     "Something went wrong" : "משהו השתבש",
     "Failed to upload {name}" : "העלאת {name} נכשלה",
-    "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג"
+    "Maximum file size of {size} exceeded" : "גודל הקבצים המרבי {size} הושג",
+    "Error creating the share" : "שגיאה ביצירת השיתוף",
+    "Share with a Deck card" : "שיתוף עם כרטיס חפיסה",
+    "Share {file} with a Deck card" : "שיתוף {file} עם כרטיס חפיסה",
+    "Share" : "שיתוף"
 },
 "nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n == 2 && n % 1 == 0) ? 1: (n % 10 == 0 && n % 1 == 0 && n > 10) ? 2 : 3;");
