@@ -13,24 +13,46 @@ OC.L10N.register(
     "{user} has removed {acl} from the board {board}" : "{user} 从面板 {board} 中移除了 {acl} ",
     "You have renamed the board {before} to {board}" : "您将面板 {before} 重命名为 {board}",
     "{user} has renamed the board {before} to {board}" : "{user} 将面板 {before} 重命名为 {board}",
-    "You have archived the board {board}" : "您已将面板 {board} 存档",
-    "{user} has archived the board {before}" : "{user} 已将面板 {before} 存档",
-    "You have unarchived the board {board}" : "您撤销了  {board} 存档",
-    "{user} has unarchived the board {before}" : "{user} 撤销了面板 {before} 存档",
+    "You have archived the board {board}" : "您已将面板 {board} 归档",
+    "{user} has archived the board {before}" : "{user} 已将面板 {before} 归档",
+    "You have unarchived the board {board}" : "您已将面板 {board} 撤销归档",
+    "{user} has unarchived the board {before}" : "{user} 已将面板 {before} 撤销归档",
     "You have created a new list {stack} on board {board}" : "您在 {board} 上创建了一个新列表 {stack}面板",
     "{user} has created a new list {stack} on board {board}" : "{user} 在 {board} 上创建了一个新列表 {stack}",
+    "You have renamed list {before} to {stack} on board {board}" : "您将面板 {board} 上的列表 {before} 重命名为 {stack}",
+    "{user} has renamed list {before} to {stack} on board {board}" : "{user} 将面板 {board} 上的列表 {before} 重命名为 {stack}",
+    "You have deleted list {stack} on board {board}" : "您删除了面板 {board} 上的列表 {stack}",
+    "{user} has deleted list {stack} on board {board}" : "{user} 删除了面板 {board} 上的列表 {stack}",
+    "You have created card {card} in list {stack} on board {board}" : "您在面板 {board} 上的列表 {stack} 中创建了卡片 {card}",
+    "{user} has created card {card} in list {stack} on board {board}" : "{user} 在面板 {board} 上的列表 {stack} 中创建了卡片 {card}",
+    "You have deleted card {card} in list {stack} on board {board}" : "您在面板 {board} 上的列表 {stack} 中删除了卡片 {card}",
+    "{user} has deleted card {card} in list {stack} on board {board}" : "{user} 在面板 {board} 上的列表 {stack} 中删除了卡片 {card}",
     "You have renamed the card {before} to {card}" : "您将卡片 {before} 重命名为 {card}",
     "{user} has renamed the card {before} to {card}" : "{user} 将卡片 {before} 重命名为 {card}",
-    "You have removed the due date of card {card}" : "您移除了到期的卡片 {card}",
-    "{user} has removed the due date of card {card}" : "{user} 移除了到期的卡片 {card}",
-    "You have set the due date of card {card} to {after}" : "您设置到期的卡片 {card} 为 {after}",
-    "{user} has set the due date of card {card} to {after}" : "{user} 设置到期的卡片 {card} 为 {after}",
-    "You have updated the due date of card {card} to {after}" : "您更新到期的卡片 {card} 为 {after}",
-    "{user} has updated the due date of card {card} to {after}" : "{user} 更新到期的卡片 {card} 为 {after}",
+    "You have added a description to card {card} in list {stack} on board {board}" : "您为面板 {board} 上的列表 {stack} 中的卡片 {card} 添加了描述",
+    "{user} has added a description to card {card} in list {stack} on board {board}" : "{user} 为面板 {board} 上的列表 {stack} 中的卡片 {card} 添加了描述",
+    "You have updated the description of card {card} in list {stack} on board {board}" : "您更新了面板 {board} 上的列表 {stack} 中的卡片 {card} 的描述",
+    "{user} has updated the description of the card {card} in list {stack} on board {board}" : "{user} 更新了面板 {board} 上，列表 {stack} 的卡片 {card}中的描述",
+    "You have archived card {card} in list {stack} on board {board}" : "您已对面板 {board} 上的列表 {stack} 中的卡片 {card} 执行归档",
+    "{user} has archived card {card} in list {stack} on board {board}" : "{user} 已对面板 {board} 上的列表 {stack} 中的卡片 {card} 执行归档",
+    "You have unarchived card {card} in list {stack} on board {board}" : "您已对面板 {board} 上的列表 {stack} 中的卡片 {card} 撤销归档",
+    "{user} has unarchived card {card} in list {stack} on board {board}" : "{user} 已对面板 {board} 上的列表 {stack} 中的卡片 {card} 撤销归档",
+    "You have removed the due date of card {card}" : "您移除了卡片 {card} 的截止日期",
+    "{user} has removed the due date of card {card}" : "{user} 移除了卡片 {card} 的截止日期",
+    "You have set the due date of card {card} to {after}" : "您将卡片 {card} 的截止日期设置为 {after}",
+    "{user} has set the due date of card {card} to {after}" : "{user} 将卡片 {card} 的截止日期设置为 {after}",
+    "You have updated the due date of card {card} to {after}" : "您将卡片 {card} 的截止日期变更为 {after}",
+    "{user} has updated the due date of card {card} to {after}" : "{user} 将卡片 {card} 的截止日期变更为 {after}",
+    "You have added the tag {label} to card {card} in list {stack} on board {board}" : "您为面板 {board} 上的列表 {stack} 中的卡片 {card} 添加了标签 {label}",
+    "{user} has added the tag {label} to card {card} in list {stack} on board {board}" : "{user} 为面板 {board} 上的列表 {stack} 中的卡片 {card} 添加了标签 {label}",
+    "You have removed the tag {label} from card {card} in list {stack} on board {board}" : "您移除了面板 {board} 上的列表 {stack} 中的卡片 {card} 的标签 {label}",
+    "{user} has removed the tag {label} from card {card} in list {stack} on board {board}" : "{user} 移除了面板 {board} 上的列表 {stack} 中的卡片 {card} 的标签 {label}",
     "You have assigned {assigneduser} to card {card} on board {board}" : "您将面板 {board} 上的卡片 {card} 指派给了 {assigneduser}",
     "{user} has assigned {assigneduser} to card {card} on board {board}" : "{user} 将面板 {board} 上的卡片 {card} 指派给了 {assigneduser}",
-    "You have unassigned {assigneduser} from card {card} on board {board}" : "您对 {assigneduser} 取消了面板 {board} 上的卡片 {card} 指派",
-    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} 对 {assigneduser} 取消了面板 {board} 上的卡片 {card} 指派",
+    "You have unassigned {assigneduser} from card {card} on board {board}" : "您不再将面板 {board} 上的卡片 {card} 指派给 {assigneduser}",
+    "{user} has unassigned {assigneduser} from card {card} on board {board}" : "{user} 不再将面板 {board} 上的卡片 {card} 指派给 {assigneduser}",
+    "You have moved the card {card} from list {stackBefore} to {stack}" : "您将卡片 {card} 从列表 {stackBefore} 移到列表 {stack}",
+    "{user} has moved the card {card} from list {stackBefore} to {stack}" : "{user} 将卡片 {card} 从列表 {stackBefore} 移到列表 {stack}",
     "You have added the attachment {attachment} to card {card}" : "您为卡片 {card}  添加了附件 {attachment}",
     "{user} has added the attachment {attachment} to card {card}" : "{user} 为卡片 {card} 添加了附件 {attachment}",
     "You have updated the attachment {attachment} on card {card}" : "您更新了卡片 {card} 中的附件 {attachment}",
@@ -47,16 +69,16 @@ OC.L10N.register(
     "A <strong>comment</strong> was created on a card" : "卡片上创建了一个 <strong>评论</strong>",
     "Upcoming cards" : "即将到来的卡片",
     "Personal" : "个人",
-    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "%s已给您指派\"%s\" 中的卡片\"%s\"。",
-    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已给您指派\"%s\" 中的卡片\"%s\"。",
-    "The card \"%s\" on \"%s\" has reached its due date." : "\"%s\"中的卡片 \"%s\"  已到期。",
+    "The card \"%s\" on \"%s\" has been assigned to you by %s." : "卡片  \"%s\" （在 \"%s\" 中）已由%s指派给您。",
+    "{user} has assigned the card \"%s\" on \"%s\" to you." : "{user} 已将卡片 \"%s\" （在 \"%s\" 中）指派给您。",
+    "The card \"%s\" on \"%s\" has reached its due date." : "卡片 \"%s\" （在 \"%s\" 中）已到期.",
     "%s has mentioned you in a comment on \"%s\"." : "%s 在 “%s” 的评论中提到了您。",
     "{user} has mentioned you in a comment on \"%s\"." : "{user} 在 “%s” 的评论中提到了您。",
     "The board \"%s\" has been shared with you by %s." : "面板 \"%s\" 已由 %s 共享给您。",
     "{user} has shared the board %s with you." : "{user} 共享面板 %s 给您。",
     "No data was provided to create an attachment." : "未能提供数据以创建附件",
-    "Finished" : "完成",
-    "To review" : "回顾",
+    "Finished" : "已完成",
+    "To review" : "待复核",
     "Action needed" : "需要操作",
     "Later" : "稍后",
     "copy" : "复制",
@@ -68,25 +90,28 @@ OC.L10N.register(
     "Example Task 1" : "示例任务 1",
     "The file was uploaded" : "文件已上传",
     "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "上传文件的大小已超过 php.ini 中 upload_max_filesize 设置的值",
-    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中 MAX_FILE_SIZE 的限制",
+    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "上传的文件长度超出了 HTML 表单中设定的 MAX_FILE_SIZE 上限",
     "The file was only partially uploaded" : "文件仅部分上传",
-    "No file was uploaded" : "没有文件被上传",
+    "No file was uploaded" : "文件未被上传",
     "Missing a temporary folder" : "缺少临时文件夹",
     "Could not write file to disk" : "无法写入文件到磁盘",
-    "A PHP extension stopped the file upload" : "PHP扩展停止了文件上传。",
+    "A PHP extension stopped the file upload" : "一个PHP扩展程序中断了文件上传。",
     "No file uploaded or file size exceeds maximum of %s" : "没有文件被上传或文件大小超出最大值 %s",
-    "Personal planning and team project organization" : "个人规划和团队项目组织",
-    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "看板是集成于 Nextcloud 中的一款看板风格的任务管理工具，用于帮助进行个人计划与项目安排。\n\n\n- 📥 把您的任务添加到卡片上，并将它们有序排列\n- 📄 将您的补充说明用markdown写下来\n- 🔖 利用指派标签更好地进行筹划\n- 👥 与您的团队，朋友或家人共享\n- 📎 附加文件并将它们嵌入到您的markdown说明中\n- 💬 用评论与您的团队讨论\n- ⚡ 在活动流中紧跟变化\n- 🚀 使您的项目井井有条",
+    "Card not found" : "未找到卡片",
+    "Path is already shared with this card" : "已和这张卡片分享了路径",
+    "Invalid date, date format must be YYYY-MM-DD" : "无效日期，日期格式必须为 YYYY-MM-DD",
+    "Personal planning and team project organization" : "个人规划和团队项目安排",
+    "Deck is a kanban style organization tool aimed at personal planning and project organization for teams integrated with Nextcloud.\n\n\n- 📥 Add your tasks to cards and put them in order\n- 📄 Write down additional notes in markdown\n- 🔖 Assign labels for even better organization\n- 👥 Share with your team, friends or family\n- 📎 Attach files and embed them in your markdown description\n- 💬 Discuss with your team using comments\n- ⚡ Keep track of changes in the activity stream\n- 🚀 Get your project organized" : "“看板”是 Nextcloud 集成的一款看板式任务管理工具，用于个人计划与项目安排。\n\n\n- 📥 将您的任务添加到卡片上，并将它们有序排列\n- 📄 将您的补充说明用markdown写下来\n- 🔖 利用指派标签更好地进行筹划\n- 👥 与您的团队，朋友或家人共享\n- 📎 附加文件并将它们嵌入到您的markdown说明中\n- 💬 用评论与您的团队讨论\n- ⚡ 在活动流中紧跟变化\n- 🚀 使您的项目井井有条",
     "Card details" : "卡片详情",
     "Add board" : "添加面板",
     "Select the board to link to a project" : "选择要链接到一个项目的面板",
     "Search by board title" : "通过标题搜索面板",
     "Select board" : "选择面板",
-    "Select the card to link to a project" : "选择要链接到一个项目的卡片",
     "Select a board" : "选择一个面板",
     "Select a card" : "选择一张卡片",
-    "Link to card" : "链接到卡片",
     "Cancel" : "取消",
+    "Select the card to link to a project" : "选择要链接到一个项目的卡片",
+    "Link to card" : "链接到卡片",
     "File already exists" : "文件已存在",
     "A file with the name {filename} already exists." : "使用文件名 {filename} 的文件已存在。",
     "Do you want to overwrite it?" : "您确定要覆盖吗？",
@@ -94,27 +119,27 @@ OC.L10N.register(
     "Keep existing file" : "保持已存在的文件",
     "This board is read only" : "此面板是只读的",
     "Drop your files to upload" : "拖放您的文件以上传",
-    "Archived cards" : "已存档卡片",
+    "Archived cards" : "已归档卡片",
     "Add list" : "添加列表",
     "List name" : "列表名称",
-    "Apply filter" : "应用过滤器",
-    "Filter by tag" : "标签筛选",
-    "Filter by assigned user" : "根据指定用户过滤",
-    "Unassigned" : "未分配",
-    "Filter by due date" : "根据截止日期过滤",
+    "Apply filter" : "应用筛选",
+    "Filter by tag" : "按标签筛选",
+    "Filter by assigned user" : "按指派的用户筛选",
+    "Unassigned" : "未指派",
+    "Filter by due date" : "按截止日期筛选",
     "Overdue" : "逾期",
     "Next 24 hours" : "未来24小时",
-    "Next 7 days" : "下个7天",
-    "Next 30 days" : "下个30天",
+    "Next 7 days" : "未来7天",
+    "Next 30 days" : "未来30天",
     "No due date" : "无截止日期",
-    "Clear filter" : "清空过滤器",
-    "Hide archived cards" : "隐藏已存档的卡片",
-    "Show archived cards" : "显示已存档的卡片",
+    "Clear filter" : "清除筛选",
+    "Hide archived cards" : "隐藏已归档卡片",
+    "Show archived cards" : "显示已归档卡片",
     "Toggle compact mode" : "切换简洁模式",
     "Details" : "详情",
     "Loading board" : "正在加载面板",
     "No lists available" : "无列表可用",
-    "Create a new list to add cards to this board" : "创建一个新列表来添加卡片到这个看板",
+    "Create a new list to add cards to this board" : "创建新列表后，即可在面板中新建卡片",
     "Board not found" : "未找到面板",
     "Sharing" : "正在共享",
     "Tags" : "标签",
@@ -122,7 +147,7 @@ OC.L10N.register(
     "Timeline" : "时间线",
     "Deleted lists" : "已删除的列表",
     "Undo" : "撤消",
-    "Deleted cards" : "已删除卡片",
+    "Deleted cards" : "已删除的卡片",
     "Share board with a user, group or circle …" : "与一个用户，群组或圈子共享面板...",
     "Searching for users, groups and circles …" : "正在搜索用户、群组和圈子 ......",
     "No participants found" : "未找到参与者",
@@ -134,23 +159,28 @@ OC.L10N.register(
     "Can manage" : "可以管理",
     "Delete" : "删除",
     "Failed to create share with {displayName}" : "用 {displayName} 创建分享失败",
-    "Add a new list" : "添加一个新列表",
-    "Archive all cards" : "存档所有卡片",
+    "Add a new list" : "添加新列表",
+    "Archive all cards" : "归档所有卡片",
     "Delete list" : "删除列表",
     "Add card" : "添加卡片",
-    "Archive all cards in this list" : "存档该列表的所有卡片",
+    "Archive all cards in this list" : "将该列表中的所有卡片归档",
     "Add a new card" : "添加一张新卡片",
     "Card name" : "卡片名",
     "List deleted" : "列表被删除",
     "Edit" : "编辑",
     "Add a new tag" : "新增一个标签",
     "title and color value must be provided" : "必须提供标题和颜色值",
-    "Board name" : "看板名",
-    "Members" : "会员",
-    "Upload attachment" : "上传附件",
+    "Board name" : "面板名称",
+    "Members" : "成员",
+    "Upload new files" : "上传新文件",
+    "Share from Files" : "从文件共享",
     "Add this attachment" : "添加此附件",
+    "Show in Files" : "在文件中显示",
+    "Unshare file" : "取消分享文件",
     "Delete Attachment" : "删除附件",
     "Restore Attachment" : "恢复附件",
+    "File to share" : "要分享的文件",
+    "Invalid path selected" : "选择的路径无效",
     "Open in sidebar view" : "在侧边栏视图中打开",
     "Open in bigger view" : "在较大视图中打开",
     "Attachments" : "附件",
@@ -161,11 +191,11 @@ OC.L10N.register(
     "No comments yet. Begin the discussion!" : "还没有评论。 开始讨论吧！",
     "Assign a tag to this card…" : "为该卡片分配标签…",
     "Assign to users" : "指派给用户",
-    "Assign to users/groups/circles" : "分配给用户/群组/圈子",
+    "Assign to users/groups/circles" : "指派给用户/群组/圈子",
     "Assign a user to this card…" : "为该卡片指派用户…",
-    "Due date" : "截至日期",
-    "Set a due date" : "设置一个截止日期",
-    "Remove due date" : "移除截至日期",
+    "Due date" : "截止日期",
+    "Set a due date" : "设置截止日期",
+    "Remove due date" : "移除截止日期",
     "Select Date" : "选择日期",
     "Save" : "保存",
     "The comment cannot be empty." : "注释不能为空。",
@@ -176,7 +206,7 @@ OC.L10N.register(
     "Description" : "描述",
     "(Unsaved)" : "（未保存的）",
     "(Saving…)" : "（正在保存...）",
-    "Formatting help" : "格式化帮助",
+    "Formatting help" : "排版指南",
     "Edit description" : "编辑描述",
     "View description" : "查看描述",
     "Add Attachment" : "添加附件",
@@ -185,9 +215,9 @@ OC.L10N.register(
     "(group)" : "（组）",
     "(circle)" : "（圈子）",
     "Assign to me" : "指派给我",
-    "Unassign myself" : "自己解除分配",
+    "Unassign myself" : "不再指派给我",
     "Move card" : "移动卡片",
-    "Unarchive card" : "恢复卡片存档",
+    "Unarchive card" : "撤销对卡片的归档",
     "Archive card" : "归档卡片",
     "Delete card" : "删除卡片",
     "Move card to another board" : "将卡片移到其他面板",
@@ -199,27 +229,27 @@ OC.L10N.register(
     "Shared with you" : "收到的共享",
     "Use bigger card view" : "使用较大的卡片视图",
     "Show boards in calendar/tasks" : "在日历/任务中显示看板",
-    "Limit deck usage of groups" : "限制群组的看板使用",
-    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "非面板创建用户组的用户将不能使用受限看板。但用户仍然能够使用已共享给他们的面板工作。",
+    "Limit deck usage of groups" : "按群组限制看板的使用权",
+    "Limiting Deck will block users not part of those groups from creating their own boards. Users will still be able to work on boards that have been shared with them." : "限制看板的使用权后，不在指定群组中的用户将不能新建面板，但仍可使用已共享给他们的面板。",
     "Board details" : "面板详情",
     "Edit board" : "编辑面板",
-    "Clone board" : "克隆看板",
-    "Unarchive board" : "取消对看板的存档",
-    "Archive board" : "存档看板",
-    "Turn on due date reminders" : "打开到期日期提醒 ",
-    "Turn off due date reminders" : "关闭到期日提醒",
-    "Due date reminders" : "到期日期提醒",
+    "Clone board" : "克隆面板",
+    "Unarchive board" : "撤销对面板的归档",
+    "Archive board" : "归档面板",
+    "Turn on due date reminders" : "打开截止日期提醒",
+    "Turn off due date reminders" : "关闭截止日期提醒",
+    "Due date reminders" : "截止日期提醒",
     "All cards" : "所有卡片",
-    "Assigned cards" : "分配的卡片",
+    "Assigned cards" : "已指派的卡片",
     "No notifications" : "无通知",
     "Delete board" : "删除看板",
     "Board {0} deleted" : "面板{0} 被删除",
-    "Only assigned cards" : "仅分配的卡片",
+    "Only assigned cards" : "仅限已指派的卡片",
     "No reminder" : "无提醒",
     "An error occurred" : "发生错误",
     "Are you sure you want to delete the board {title}? This will delete all the data of this board." : "你确定你要删除 {title}面板吗？面板内所有数据都将因此被删除。",
     "Delete the board?" : "是否删除面板？",
-    "Loading filtered view" : "正在加载已过滤视图",
+    "Loading filtered view" : "正在加载已筛选的视图",
     "Today" : "今天",
     "Tomorrow" : "明天",
     "This week" : "本周",
@@ -228,8 +258,12 @@ OC.L10N.register(
     "upcoming cards" : "即将到来的卡片",
     "Link to a board" : "链接到一个面板",
     "Link to a card" : "链接到一张卡片",
-    "Something went wrong" : "有地方出错了",
+    "Something went wrong" : "发生了错误",
     "Failed to upload {name}" : "未能上传 {name}",
-    "Maximum file size of {size} exceeded" : "文件大小 {size} 超出最大限制"
+    "Maximum file size of {size} exceeded" : "文件容量已超过 {size} 的上限",
+    "Error creating the share" : "创建分享出错",
+    "Share with a Deck card" : "分享给一张看板卡片",
+    "Share {file} with a Deck card" : "将{file}分享给一张看板卡片",
+    "Share" : "分享"
 },
 "nplurals=1; plural=0;");
